@@ -9,6 +9,7 @@ from python_framework.api.src.util import Serializer
 from python_framework.api.src.converter.static import ConverterStatic
 from python_framework.api.src.enumeration.HttpStatus import HttpStatus
 from python_framework.api.src.service.flask import FlaskManager
+from python_framework.api.src.service import ExceptionHandler
 from python_framework.api.src.service.openapi import OpenApiManager
 from python_framework.api.src.util import ClientUtil
 from python_framework.api.src.util.ClientUtil import HttpClientEvent, ManualHttpClientEvent
@@ -371,6 +372,14 @@ def HttpClientMethod(
                             *httpClientEvent.args,
                             **httpClientEvent.kwargs
                         )
+                    except requests.exceptions.ReadTimeout as readTimeoutException:
+                        raise ExceptionHandler.getClientGlobalException(
+                            resourceMethodResponse,
+                            HttpDomain.EMITTER_CONTEXT,
+                            str(exception),
+                            exception = readTimeoutException,
+                            status = HttpStatus.REQUEST_TIMEOUT
+                        )
                     except Exception as exception:
                         ClientUtil.raiseException(clientResponse, exception)
                     ClientUtil.raiseExceptionIfNeeded(clientResponse)
